@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2011 Björn Larsson
+# Copyright 2011 - 2013 Björn Larsson
 
 # This file is part of pytvdbapi.
 #
@@ -25,11 +25,11 @@ A clean, resource friendly and easy to use API for thetvdb.com_.
 
 import logging
 try:
-    from logging import NullHandler
+    from logging import NullHandler  # pylint: disable=E0611
 except ImportError:
     from pytvdbapi.backport import NullHandler
 
-__VERSION__ = (0, 3, 0)
+__VERSION__ = (0, 4, 0)
 __NAME__ = 'pytvdbapi'
 __EMAIL__ = 'develop@bjornlarsson.net'
 
