@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2011 Björn Larsson
+# Copyright 2011 - 2013 Björn Larsson
 
 # This file is part of pytvdbapi.
 #
@@ -18,22 +18,24 @@
 # along with pytvdbapi.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-A module containing all the errors raised by pytvdbapi.
+A module containing all the exceptions raised by *pytvdbapi*.
 
-pytvdbapi will only raise exceptions that are of type :class:`PytvdbapiError`.
+*pytvdbapi* will only raise exceptions that are of type :class:`PytvdbapiError` or it's subclasses.
 """
 
 import logging
 
 __all__ = ['PytvdbapiError', 'BadData', 'ConnectionError',
-           'TVDBAttributeError', 'TVDBIndexError']
+           'TVDBAttributeError', 'TVDBIndexError', 'TVDBIdError',
+           'TVDBValueError', 'TVDBNotFoundError']
 
 #Module level logger
-logger = logging.getLogger(__name__)  # pylint: disable=C0103
+logger = logging.getLogger(__name__)
 
 
 class PytvdbapiError(Exception):
     """Base exception for all exceptions raised by pytvdbapi"""
+
     def __init__(self, msg, *args, **kwargs):
         super(PytvdbapiError, self).__init__(msg, args, kwargs)
         logger.error(msg)
@@ -47,31 +49,30 @@ class BadData(PytvdbapiError):
     pass
 
 
+# pylint: disable=W0622, W0511
+# TODO: Change this name so it does not collide with the builtin name and remove the lint directive
 class ConnectionError(PytvdbapiError):
     """
-    Raised by the :class:`Loader` when unable to connect to the provided URL.
+    Raised by the :class:`pytvdbapi.Loader` when unable to connect to the provided URL.
     """
     pass
 
 
-class TVDBAttributeError(PytvdbapiError):
+class TVDBAttributeError(PytvdbapiError, AttributeError):
     """
-    A replacement for the standard AttributeError. Will be raised when
-    accessing invalid attributes of :class:`Show` and :class:`Episode`
-    instances
+    A replacement for the standard AttributeError.
     """
     pass
 
 
-class TVDBIndexError(PytvdbapiError):
+class TVDBIndexError(PytvdbapiError, IndexError):
     """
-    A replacement for the standard IndexError. Will be raised when accessing
-    invalid indexes of :class:`Show` and :class:`Season` instances.
+    A replacement for the standard IndexError.
     """
     pass
 
 
-class TVDBValueError(PytvdbapiError):
+class TVDBValueError(PytvdbapiError, ValueError):
     """
     A replacement for the standard ValueError exception.
     """
@@ -81,3 +82,8 @@ class TVDBValueError(PytvdbapiError):
 class TVDBIdError(PytvdbapiError):
     """Raised when trying to get a show using an invalid Show ID"""
     pass
+
+
+class TVDBNotFoundError(PytvdbapiError):
+    """Raised when the data can not be found. Represent the 404 http code."""
+    pass
